#
# Copyright (C) 1997 Ken MacLeod
# See the file COPYING for distribution terms.
#
# $Id: SData.pm,v 1.2 1997/10/06 03:52:03 ken Exp $
#

# Internally, an SGML::SData is blessed scalar

package SGML::SData;

use strict;

=head1 NAME

SGML::SData - an SGML, XML, or HTML document SData replacement

=head1 SYNOPSIS

  $data = $sdata->data;

I<more to come, including iterators, C<new>, and C<as_string>>

=head1 DESCRIPTION

C<SGML::SData> objects are loaded by C<SGML::SPGrove>.  An
C<SGML::SData> contains the replacement value of a character entity
reference.

C<$element-E<gt>data> returns the data of the SData object.

The Perl module C<Text::EntityMap> can be used to map commonly used
character entity sets to common output formats.

=head1 AUTHOR

Ken MacLeod, ken@bitsko.slc.ut.us

=head1 SEE ALSO

perl(1), SGML::SPGrove(3), Text::EntityMap(3), SGML::Element(3),
SGML::PI(3).

=cut

sub data {
    return $_[0];		# XXX de-reference?
}

sub accept {
    my ($self) = shift;
    my ($visitor) = shift;

    $visitor->visit_sdata ($self, @_);
}

1;
