#
# Copyright (C) 1997 Ken MacLeod
# See the file COPYING for distribution terms.
#
# $Id: SPGrove.pm,v 1.3 1997/10/06 03:52:04 ken Exp $
#

# Internally, an SGML::SPGrove is an array containing
#
#    [0] -- errors
#    [1] -- root element

package SGML::SPGrove;

use strict;
use vars qw($VERSION @ISA @EXPORT);

require Exporter;
require DynaLoader;

@ISA = qw(Exporter DynaLoader);

$VERSION = '0.02';

bootstrap SGML::SPGrove $VERSION;

sub errors {
    return $_[0]->[0];
}
    
sub root {
    return $_[0]->[1];
}

sub accept {
    my ($self) = shift;
    my ($visitor) = shift;

    $visitor->visit_grove ($self, @_);
}

1;
__END__

=head1 NAME

SGML::SPGrove - load an SGML, XML, or HTML document

=head1 SYNOPSIS

  use SGML::SPGrove;
  $grove = SGML::SPGrove->new ($sysid);
  $root = $grove->root;
  $errors = $grove->errors;

I<more to come, including iterators, more constructors, and
C<as_string>>

=head1 DESCRIPTION

C<new> loads an SGML, XML, or HTML document instance from C<$sysid>
using James Clark's SGML Parser (SP), returning a ``grove'' that
contains the root, or top, element of the document and an array of any
warnings or errors that may have been generated while parsing the
document.

Note that there will be a significant number of errors when loading an
XML or HTML document without a Document Type Definition (DTD).

Refer to ``System Identifiers'' in SP's documentation for a
description of C<$sysid>, which can be a file name, a URL, `C<->' for
standard input, a literal string ("C<E<lt>LITERALE<gt>$scalar>"), or a
formal system identifier.

C<$grove-E<gt>root> returns the C<SGML::Element> of the outermost
element of the document.

C<$grove-E<gt>errors> returns a reference to array containing any
errors generated while parsing the document.

=head1 AUTHOR

Ken MacLeod, ken@bitsko.slc.ut.us

=head1 SEE ALSO

perl(1), Text::EntityMap(3), SGML::Element(3), SGML::SData(3),
SGML::PI(3).
<http://www.jclark.com/>

=cut
